Hello!

I'm pleased to announce version 3.0.0b2, the second beta of the upcoming
release of branch 3.0 of CheetahTemplate3.


What's new in CheetahTemplate3
==============================

Minor changes in the release process.


What is CheetahTemplate3
========================

Cheetah3 is a free and open source template engine.
It's a fork of the original CheetahTemplate library.

Python 2.7 or 3.3+ is required.


Where is CheetahTemplate3
=========================

Site:
http://cheetahtemplate.org/

Development:
https://github.com/CheetahTemplate3

Download:
https://pypi.python.org/pypi/Cheetah3/3.0.0b2

News and changes:
http://cheetahtemplate.org/news.html
